import * as insuranceClaimServices from '@/services/api/InsuranceClaim';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { useQuery, useQueryClient } from '@tanstack/vue-query';

type UseInsuranceOrderMaterialListOptions = {
  insuranceOrderId: MaybeRef<string>;
};

export function useInsuranceOrderMaterialList({
  insuranceOrderId,
}: UseInsuranceOrderMaterialListOptions) {
  const { data: insuranceOrderMaterialList, refetch } = useQuery({
    queryKey: ['insuranceOrderServices/getInsuranceOrderMaterialList', insuranceOrderId],
    queryFn: async () => {
      let res = await insuranceOrderServices.getInsuranceOrderMaterialList(
        {
          id: unref(insuranceOrderId),
        },
        { showLoading: false }
      );
      return res;
    },
    placeholderData: () => [] as API.InsuranceOrderMaterialListOutput[],
    enabled: computed(() => !!unref(insuranceOrderId)),
  });

  return {
    insuranceOrderMaterialList,
    refetch,
  };
}
